# AWS Connector

This tool provides a AWS CLI connector where you can switch roles to the account you want access to. 

# Get started
## Generate config
Copy the file config/config_template.yaml to config/config.yaml and fill in the file before you start.

## Install dependencies
```
 python3 setup.py install
```

## Start the tool
```
 python3 src/aws_connector.py
```

